@@ -24,7 +24,7 @@ copyright = '2021, Pradyumna Paranjape'
 author = 'Pradyumna Paranjape'
 
 # The full version, including alpha/beta/rc tags
-release = '1.0.0'
+release = '1.0.1'
 
 # -- General configuration ---------------------------------------------------
 
@@ -34,7 +34,7 @@ release = '1.0.0'
 extensions = [
     'sphinx.ext.todo', 'sphinx.ext.autodoc', 'sphinx.ext.viewcode',
     'sphinx.ext.napoleon', 'sphinx_rtd_theme', 'sphinx_autodoc_typehints',
-    'sphinxarg.ext'
+    'sphinxarg.ext', 'sphinx_panels'
 ]
 
 # Add any paths that contain templates here, relative to this directory.
