@@ -21,8 +21,8 @@
 Create a python project directory structure with all necessary files, folders
 '''
 
-from .read_templates import INFO_BASE
+from pyprojstencil.read_templates import INFO_BASE
 
 __all__ = ['INFO_BASE']
 
-__version__ = "1.0.0"
+__version__ = "1.0.1"
