@@ -23,7 +23,7 @@ commonly used functions
 
 from pathlib import Path
 
-from .configure import PyConfig
+from pyprojstencil.configure import PyConfig
 
 
 def edit_modify(text: str, config: PyConfig) -> str:
