@@ -26,7 +26,7 @@ trimming all unnecessary history
 
 from virtualenv import cli_run
 
-from .configure import PyConfig
+from pyprojstencil.configure import PyConfig
 
 
 def init_venv(config: PyConfig):
